@@ -7,6 +7,8 @@ cmhc_region_params_from_census <- function(GeoUID){
   cmhc_geography_type_list=list(C=1,PR=2,CMA=3, CSD=4, CT=7, ZONE=5,NEIGHBOUHOOD=6)
   list <- list("geography_type_id"=as.character(cmhc_geography_type_list[cmhc_geo_level_for_census(GeoUID)]),
                "geography_id"=census_to_cmhc_geocode(GeoUID))
+  metid <- cmhc_met_id_for_census(GeoUID)
+  if (!is.na(metid)) list$MetId <- metid
   return(list)
 }
 
@@ -68,6 +70,50 @@ census_to_cmhc_geocode <- function(GeoUID){
   result
 }
 
+#' translate census to CMHC met id, if applicable
+#' @param GeoUID Census geographic identifier for CMA or CSD
+#' @keywords internal
+#' @noRd
+#' @return a character string with the CMHC MetId
+cmhc_met_id_for_census <- function(GeoUID) {
+  cmhc_name <- list(
+    "CT"="CMHCCT_UID",
+    "CSD"="CMHC_CSDUID",
+    "CMA"="METCODE"
+  )
+  census_name <- list(
+    "CT"="CTUID",
+    "CSD"="CSDUID",
+    "CMA"="CMAUID"
+  )
+  geo_level = cmhc_geo_level_for_census(GeoUID)
+
+  if (is.null(geo_level)) stop("Could not recognize GeoUID.")
+
+  if (geo_level=="CSD") {
+    cma_id <- cancensus::list_census_regions("2021") %>%
+      dplyr::filter(.data$region==GeoUID) %>%
+      dplyr:: pull(.data$CMA_UID)
+    if (nchar(cma_id)==3) {
+      pr_uid <- substr(GeoUID,1,2)
+      cma_id <- paste0(pr_uid,cma_id)
+    }
+    cmhc_cma_id <- cmhc::cmhc_cma_translation_data %>%
+      filter(.data$CMA_UID==cma_id) %>%
+      pull(.data$METCODE)
+  }
+
+  result <- switch(
+    geo_level,
+    "CMA" = cmhc::cmhc_cma_translation_data %>% mutate(CMA_UID=ifelse(nchar(GeoUID)==3 & nchar(.data$CMA_UID)==5,substr(.data$CMA_UID,3,5),.data$CMA_UID)) %>% filter(.data$CMA_UID==GeoUID) %>% pull(.data$METCODE),
+    "CT" = cmhc::cmhc_ct_translation_data %>% filter(.data$CTUID==GeoUID) %>% pull(.data$METCODE) %>% unique(),
+    "CSD" = cmhc_cma_id,
+    "PR" = NA_character_
+  )
+
+  result
+}
+
 #' translate CMHC to census geographic identifier
 #' @param GeoUID CMHC geographic identifier for CMA or CSD or CT
 #' @param parent_region census geographic identifier to identify CMA if needed
@@ -102,8 +148,8 @@ cmhc_to_census_geocode <- function(GeoUID,parent_region=NULL){
         if (parent_geo_level=="CMA") {
           CMA_GEOUID <- parent_region
         } else if (parent_geo_level=="CSD"){
-          link <- cmhc::cmhc_ct_translation_data |>
-            filter(.data$CSDUID==parent_region) |>
+          link <- cmhc::cmhc_ct_translation_data %>%
+            filter(.data$CSDUID==parent_region) %>%
             select(.data$CTUID,.data$CMHC_CT) %>%
             mutate(CMA_UID=substr(.data$CTUID,1,3))
           CMA_GEOUID <- unique(link$CMA_UID)
